<?php

/**
 * Get node types options.
 * 
 * @return
 *   Associative array of options. 
 */
function node_field_node_types_options() {
  $options = array();
  
  // Populate node types options.
  $node_field_types = node_type_get_types();
  foreach ($node_field_types as $node_field_type) {
    $options[$node_field_type->type] = $node_field_type->name;
  }
  
  return $options;
}

/**
 * Get node field types options.
 * 
 * @return
 *   Associative array of options. 
 */
function node_field_node_field_types_options() {
  $options = array();
  
  // Populate node field types options.
  $node_field_types = node_field_types_info();
  foreach ($node_field_types as $node_field_type) {
    $options[$node_field_type['type']] = $node_field_type['label'];
  }
  
  return $options;
}

/**
 * Get node field widget form.
 * 
 * @param $type
 *   Requested node field type.
 * 
 * @return
 *   Form array.
 */
function node_field_node_field_widget_form($type, $node_field) {
  $form = array();
  
  $node_field_types = node_field_types_info();
  
  $function = isset($node_field_types[$type]['widget']) ? $node_field_types[$type]['widget'] : FALSE;
  
  if ($function && is_callable($function)) {
    $form = $function($node_field);
    foreach (element_children($form) as $element) {
      $form[$element]['#attributes']['class'][] = 'node-field-values';
    }
  }
  
  return $form;
}

/**
 * Get node field formatter.
 * 
 * @param $type
 *   Requested node field type.
 * 
 * @return
 *   Form array.
 */
function node_field_node_field_formatter($node_fields) {
  $node_field_types = node_field_types_info();
  
  foreach ($node_fields as &$node_field) {
    $function = isset($node_field_types[$node_field['type']]['formatter']) ? $node_field_types[$node_field['type']]['formatter'] : FALSE;
  
    if ($function && is_callable($function)) {
      $node_field['value'] = $function($node_field);
    }
  }
  
  return $node_fields;
}


/**
 * Adding node_fields to node content.
 * @param $node
 *   Object of node.
 * @param $node_fields 
 *   Array of node fields.
 */
function node_field_node_content_add_node_fields($node, $node_fields) {
  $node_fields = node_field_node_field_formatter($node_fields);
  $node->content['node_fields'] = array(
    '#theme_wrappers' => array('node_field_fields'),
  );
  foreach ($node_fields as $node_field) {
    $node->content['node_fields'][] = array(
      '#theme' => 'node_field_field',
      '#node_field' => $node_field,
    );
  }
}
