<?php

/**
 * Node field types info. 
 */
function node_field_types_info() {
  $items = array();
  
  $items['text'] = array(
    'type' => 'text',
    'label' => t('Text'),
    'widget' => 'node_field_text_widget',
  );
  $items['text_long'] = array(
    'type' => 'text_long',
    'label' => t('Long text'),
    'widget' => 'node_field_text_long_widget',
  );
  $items['link'] = array(
    'type' => 'link',
    'label' => t('Link'),
    'widget' => 'node_field_link_widget',
    'formatter' => 'node_field_link_formatter',
  );
  if (module_exists('date_popup')) {
    $items['date'] = array(
      'type' => 'date',
      'label' => t('Date'),
      'widget' => 'node_field_date_widget',
    );
  }
  if (module_exists('taxonomy')) {
    $items['taxonomy'] = array(
      'type' => 'taxonomy',
      'label' => t('Vocabulary'),
      'widget' => 'node_field_taxonomy_widget',
      'formatter' => 'node_field_taxonomy_formatter',
    );
  }
  
  return $items;
}

/**
 * Widget for text field.
 * 
 * @return
 *   Form array.
 */
function node_field_text_widget($node_field) {
  $form = array();
  $form['value'] = array(
    '#type' => 'textfield',
    '#title' => t('Value'),
    '#default_value' => $node_field['value'],
  );
  return $form;
}

/**
 * Widget for long text field.
 * 
 * @return
 *   Form array.
 */
function node_field_text_long_widget($node_field) {
  $form = array();
  $form['value'] = array(
    '#type' => 'textarea',
    '#title' => t('Value'),
    '#default_value' => $node_field['value'],
  );
  return $form;
}

/**
 * Widget for link field.
 */
function node_field_link_widget($node_field) {
  $form = array();
  $form['options']['url'] = array(
    '#type' => 'textfield',
    '#title' => t('Url address'),
    '#default_value' => $node_field['options']['url'],
  );
  $form['value'] = array(
    '#type' => 'textfield',
    '#title' => t('Value'),
    '#default_value' => $node_field['value'],
  );
  return $form;
}

function node_field_link_formatter($node_field) {
  $link = l($node_field['value'], $node_field['options']['url']);
  return $link;
}
/**
 * Widget for image field.
 * 
 * @return
 *   Form array.
 */
function node_field_date_widget($node_field) {
  $form = array();
  $form['value'] = array(
    '#type' => 'date_popup',
    '#title' => t('Value'),
    '#date_format' => 'm/d/Y',
    '#date_year_range' => '-90:+10',
    '#default_value' => $node_field['value'],
  );
  return $form;
}

/**
 * Widget for taxonomy field.
 * 
 * @return
 *   Form array.
 */
function node_field_taxonomy_widget($node_field) {
  $wrapper_id = 'node-field-value-wrapper-' . $node_field['id'];
  $vocs_options = array();
  $terms_options = array();
  $vocs = taxonomy_vocabulary_get_names();
  foreach ($vocs as $id => $voc) {
    $vocs_options[$voc->vid] = $voc->name;
  }
  $form = array();
  $form['options'] = array(
    '#tree' => TRUE,
  );
  $form['options']['vocs'] = array(
    '#type' => 'select',
    '#title' => t('Vocabularies'),
    '#options' => $vocs_options,
    '#empty_option' => t('- Select -'),
    '#default_value' => $node_field['options']['vocs'],
    '#ajax' => array(
      'callback' => 'node_field_taxonomy_widget_js',
      'wrapper' => $wrapper_id,
      'method' => 'replace',
      'effect' => 'fade',
    ),
  );
  if ($node_field['options']['vocs']) {
    $terms = taxonomy_get_tree($node_field['options']['vocs']);
    foreach ($terms as $term) {
      $terms_options[$term->tid] = $term->name;
    }
  }
  $form['value'] = array(
    '#type' => 'select',
    '#title' => t('Value'),
    '#options' => $terms_options,
    '#default_value' => $node_field['value'],
    '#prefix' => '<div id="' . $wrapper_id . '">',
    '#suffix' => '</div>',
    '#disabled' => empty($node_field['options']['vocs']) ? TRUE : FALSE,
  );
  return $form;
}
/**
 * Widget ajax callback.
 */
function node_field_taxonomy_widget_js($form, &$form_state) {
  $node_field_path = $form_state['triggering_element']['#array_parents'];
  array_pop($node_field_path);
  array_pop($node_field_path);
  
  $node_field = drupal_array_get_nested_value($form, $node_field_path);
  return $node_field['value'];
}

/**
 * Formatter for taxonomy field.
 * 
 * @return
 *   Form array.
 */
function node_field_taxonomy_formatter($node_field) {
  $term = taxonomy_term_load($node_field['value']);
  $link = l($term->name, 'taxonomy/term/' . $term->tid);
  return $link;
}
