<?php

/**
 * Add new fields in database.
 * 
 * @param array $field
 *   Associative field array.
 * 
 * @return SAVED_NEW/FALSE
 *   If the record insert failed, returns FALSE. If it succeeded, returns SAVED_NEW.
 */
function node_field_db_field_insert(&$field) {
  return drupal_write_record('node_field', $field);
}

/**
 * Update fields in database.
 * 
 * @param array $field
 *   Associative field array.
 * @param array $keys
 *   Indexed array of keys. This keys will be added in conditions with values from $field.
 * 
 * @return SAVED_UPDATED/FALSE
 *   If the record update failed, returns FALSE. If it succeeded, returns SAVED_UPDATED.
 */
function node_field_db_field_update(&$field, $keys) {
  return drupal_write_record('node_field', $field, $keys);
}

/**
 * Delete fields from database.
 * 
 * @param array $field
 *   Associative field array.
 * @param array $keys
 *   Indexed array of keys. This keys will be added in conditions with values from $field.
 * 
 * @return numeric
 *   Count of deleted records.
 */
function node_field_db_field_delete($field, $keys) {
  
  $query = db_delete('node_field');
  foreach ($keys as $key) {
    $query = $query->condition($key, $field[$key]);
  }
  $output = $query->execute();
  
  return $output;
}

/**
 * Get fields from database.
 * 
 * @param array $field
 *   Associative field array.
 * @param array $keys
 *   Indexed array of keys. This keys will be added in conditions with values from $field.
 * 
 * @return array
 *   Array of fields arrays.
 */
function node_field_db_field_select($field, $keys) {
  $query = db_select('node_field', 'nf');
  $query->fields('nf');
  foreach ($keys as $key) {
    $query->condition('nf.' . $key, $field[$key]);
  }
  $result = $query->execute();
  
  $node_fields = $result->fetchAll(PDO::FETCH_ASSOC);
  
  foreach ($node_fields as $key => $node_field) {
    if (!empty($node_field['options'])) {
      $node_fields[$key]['options'] = unserialize($node_field['options']);
    }
  }
  
  return $node_fields;
}
